Description for setup.py

Usage: python setup.py build
       which will generate the qconf_py library in build/lib.linux-x86_64-X.X as qconf_py.so

Paramters of Extension:
    name : the full name of the extension, including any packages ? ie. not a filename or pathname, but Python dotted name;

    sources : list of source filenames, relative to the distribution root (where the setup script lives), in Unix form (slash- separated) for portability. Source files may be C, C++, SWIG (.i), platform-specific resource files, or whatever else is recognized by the build_ext command as source for a Python extension.
    
    include_dirs : list of directories to search for C/C++ header files (in Unix form for portability);

    extra_objects : list of extra files to link with (eg. object files not implied by ¡®sources¡¯, static library that must be explicitly specified, binary resource files, etc.)

    library_dirs : list of directories to search for C/C++ libraries at link time

    libraries : list of library names (not filenames or paths) to link against
